using System;
using System.Text.Json.Serialization;
namespace org.accordproject.commonmark {
   using concerto;
   abstract class Node : Concept {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "org.accordproject.commonmark.Node";
      public string text { get; set; }
      public Node[] nodes { get; set; }
      public int line { get; set; }
      public int column { get; set; }
      public int position { get; set; }
      public int startTagPosition { get; set; }
   }
   abstract class Root : Node {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "org.accordproject.commonmark.Root";
   }
   abstract class Child : Node {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "org.accordproject.commonmark.Child";
   }
   class Text : Child {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "org.accordproject.commonmark.Text";
   }
   class Attribute : Concept {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "org.accordproject.commonmark.Attribute";
      public string name { get; set; }
      public string value { get; set; }
   }
   class TagInfo : Concept {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "org.accordproject.commonmark.TagInfo";
      public string tagName { get; set; }
      public string attributeString { get; set; }
      public Attribute[] attributes { get; set; }
      public string content { get; set; }
      public bool closed { get; set; }
   }
   class CodeBlock : Child {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "org.accordproject.commonmark.CodeBlock";
      public string info { get; set; }
      public TagInfo tag { get; set; }
   }
   class Code : Child {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "org.accordproject.commonmark.Code";
      public string info { get; set; }
   }
   class HtmlInline : Child {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "org.accordproject.commonmark.HtmlInline";
      public TagInfo tag { get; set; }
   }
   class HtmlBlock : Child {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "org.accordproject.commonmark.HtmlBlock";
      public TagInfo tag { get; set; }
   }
   class Emph : Child {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "org.accordproject.commonmark.Emph";
   }
   class Strong : Child {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "org.accordproject.commonmark.Strong";
   }
   class BlockQuote : Child {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "org.accordproject.commonmark.BlockQuote";
   }
   class Heading : Child {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "org.accordproject.commonmark.Heading";
      public string level { get; set; }
   }
   class ThematicBreak : Child {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "org.accordproject.commonmark.ThematicBreak";
   }
   class Softbreak : Child {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "org.accordproject.commonmark.Softbreak";
   }
   class Linebreak : Child {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "org.accordproject.commonmark.Linebreak";
   }
   class Link : Child {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "org.accordproject.commonmark.Link";
      public string destination { get; set; }
      public string title { get; set; }
   }
   class Image : Child {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "org.accordproject.commonmark.Image";
      public string destination { get; set; }
      public string title { get; set; }
   }
   class Paragraph : Child {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "org.accordproject.commonmark.Paragraph";
   }
   class List : Child {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "org.accordproject.commonmark.List";
      public string type { get; set; }
      public string start { get; set; }
      public string tight { get; set; }
      public string delimiter { get; set; }
   }
   class Item : Child {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "org.accordproject.commonmark.Item";
   }
   class Document : Root {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "org.accordproject.commonmark.Document";
      public string xmlns { get; set; }
   }
}
